import { Label } from './Label.interface';
import { SearchQuery } from './SearchQuery.interface';
export interface Message {
    messageId: string;
    threadId: string;
    labelIds: string[];
    snippet: string;
    historyId: string;
    /**
     * unix ms timestamp string
     */
    internalDate: string;
    headers: any[];
    body: {
        html: string | undefined;
        text: string | undefined;
    };
}
export declare class Inbox {
    private credentialsJsonPath;
    private tokenPath;
    private gmailApi;
    private authenticated;
    constructor(credentialsJsonPath: string, tokenPath?: string);
    authenticateAccount(): Promise<void>;
    getAllLabels(): Promise<Label[]>;
    /**
     * Retrieves all existing emails
     */
    getInboxMessages(): Promise<Message[]>;
    /**
     * Finds existing emails
     *
     * Example search query
     * - "has:attachment filename:salary.pdf largerThan:1000000 label:(paychecks salaries) from:myoldcompany@oldcompany.com"
     * - {
     *   has: "attachment",
     *   filename: "salary.pdf",
     *   largerThanInBytes: 1000000,
     *   labels: ["paychecks", "salaries"],
     *   from: "myoldcompany@oldcompany.com"
     * }
     */
    findMessages(searchQuery: SearchQuery | string | undefined): Promise<Message[]>;
    private getMessageById;
    private guardAuthentication;
    private arrayToAdvancedSearchString;
    private mapSearchQueryToSearchString;
}
